@@ -4,12 +4,19 @@
 #' @importFrom tibble rownames_to_column
 NULL
 
-#' Function to update parameters from a TROLL outputs for a next simulation.
+#' Update global parameters
+#'
+#' `update_parameters()` update the global parameters used in the `TROLL`
+#' simulation from a TROLL outputs for a next simulation. All parameters have a
+#' default value used in French Guiana simulations.
 #'
 #' @param sim trollsim.
-#' @param ... parameters to update and their values..
+#' @param ... parameters to update and their values (see [generate_parameters()]
+#'   for a complete list).
 #'
-#' @return data.frame
+#' @return a [data.frame()]
+#'
+#' @seealso [troll()], [stack()], [generate_parameters()]
 #'
 #' @examples
 #'
@@ -28,7 +35,7 @@ setGeneric("update_parameters", function(sim, ...) {
 #' @rdname update_parameters
 #' @export
 setMethod("update_parameters", "trollsim", function(sim, ...) {
-  V1 <- description <- newvalue <- oldvalue <- param <- value <- NULL
+  V1 <- description <- newvalue <- oldvalue <- param <- value <- NULL # nolint
   sim@inputs$global %>%
     rename(oldvalue = value) %>%
     left_join(list(...) %>%
